@@ -22,7 +22,7 @@ use Log::Scrubber qw(disable $SCRUBBER scrubber :Carp scrubber_add_scrubber);
 @ISA     = qw(Business::OnlinePayment::HTTPS);
 $me      = 'Business::OnlinePayment::Litle';
 $DEBUG   = 0;
-our $VERSION = '0.953'; # VERSION
+our $VERSION = '0.954'; # VERSION
 
 # PODNAME: Business::OnlinePayment::Litle
 
@@ -1269,13 +1269,16 @@ sub _sftp_connect {
     my ($self,$args,$dir) = @_;
     $self->_die("Missing ftp_username") if ! $args->{'ftp_username'};
     $self->_die("Missing ftp_password") if ! $args->{'ftp_password'};
+    my $more_args = [];
+    push @$more_args, ( -o => 'UserKnownHostsFile=' . $args->{'sftp_hosts_file'} ) if $args->{'sftp_hosts_file'};
     require Net::SFTP::Foreign;
     my $sftp = Net::SFTP::Foreign->new(
         $self->server(),
-        timeout  => $args->{'ftp_timeout'} || 90,
+        timeout        => $args->{'ftp_timeout'} || 90,
         stderr_discard => 1,
-        user     => $args->{'ftp_username'},
-        password => $args->{'ftp_password'},
+        user           => $args->{'ftp_username'},
+        password       => $args->{'ftp_password'},
+        more           => $more_args,
     );
     $sftp->error and $self->_die("SSH connection failed: " . $sftp->error);
 
@@ -1736,7 +1739,7 @@ Business::OnlinePayment::Litle - Business::OnlinePayment::Litle - Vantiv (was Li
 
 =head1 VERSION
 
-version 0.953
+version 0.954
 
 =head1 SYNOPSIS
 
@@ -2192,7 +2195,7 @@ Jason Hall <jayce@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Daina Pettit David Bartle Jason (Jayce^) Hall Terry
+=for stopwords Daina Pettit David Bartle Jason Hall (Jayce^) Terry
 
 =over 4
 
@@ -2206,6 +2209,10 @@ David Bartle <captindave@gmail.com>
 
 =item *
 
+Jason Hall <jayce@jaycehall.com>
+
+=item *
+
 Jason (Jayce^) Hall <jayce@lug-nut.com>
 
 =item *
@@ -2216,7 +2223,7 @@ Jason Terry <oaxlin@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Jason Hall.
+This software is copyright (c) 2017 by Jason Hall.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
